Crate vector_text_hershey

Crate vector_text_hershey 

vector-text-hershey is a backend for the vector-text crate that renders Hershey fonts.

It includes Hershey font data sourced from Paul Bourke’s compilation.

Structs

HersheyRenderer
A Renderer which draws text using Hershey fonts.

Enums

HersheyFont
A specific Hershey font mapping file which defines a font in terms of symbol ranges (.hmp file).