HersheyFont

Enum HersheyFont 

pub enum HersheyFont {
Show 28 variants Scripts, Romans, Astrol, Uppmat, Gothita, Italicc, Gothger, Cyrilc, Symbol, Romant, Romanc, Italiccs, Japan, Romand, Misc, Meteo, Lowmat, Music, Gotheng, Greekp, Greekcs, Greekc, Italict, Marker, Romanp, Scriptc, Greeks, Romancs,
}
A specific Hershey font mapping file which defines a font in terms of symbol ranges (.hmp file).

Variants



Scripts



Romans



Astrol



Uppmat



Gothita



Italicc



Gothger



Cyrilc



Symbol



Romant



Romanc



Italiccs



Japan



Romand



Misc



Meteo



Lowmat



Music



Gotheng



Greekp



Greekcs



Greekc



Italict



Marker



Romanp



Scriptc



Greeks



Romancs